Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(114)

Unified Diff: services/ui/ws/gpu_compositor_frame_sink.h

Issue 2494663004: Mus+Ash: ServerWindowCompositorFrameSink => GpuCompositorFrameSink (Closed)
Patch Set: ServerWindowCompositorFrameSinkManager should not reference SurfaceFactory or SurfaceManager Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « services/ui/ws/BUILD.gn ('k') | services/ui/ws/gpu_compositor_frame_sink.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: services/ui/ws/gpu_compositor_frame_sink.h
diff --git a/services/ui/ws/server_window_compositor_frame_sink.h b/services/ui/ws/gpu_compositor_frame_sink.h
similarity index 83%
rename from services/ui/ws/server_window_compositor_frame_sink.h
rename to services/ui/ws/gpu_compositor_frame_sink.h
index efcf46bfd04185a5b4afef7f944b94364d9b811d..65a7b82d952777b4bcfa93f4f61efdb4bf78b31b 100644
--- a/services/ui/ws/server_window_compositor_frame_sink.h
+++ b/services/ui/ws/gpu_compositor_frame_sink.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef SERVICES_UI_WS_SERVER_WINDOW_COMPOSITOR_FRAME_SINK_H_
-#define SERVICES_UI_WS_SERVER_WINDOW_COMPOSITOR_FRAME_SINK_H_
+#ifndef SERVICES_UI_WS_GPU_COMPOSITOR_FRAME_SINK_H_
+#define SERVICES_UI_WS_GPU_COMPOSITOR_FRAME_SINK_H_
#include <memory>
#include <set>
@@ -39,17 +39,16 @@ class DisplayCompositor;
namespace ws {
// Server side representation of a WindowSurface.
-class ServerWindowCompositorFrameSink
- : public cc::mojom::MojoCompositorFrameSink,
- public cc::DisplayClient,
- public cc::mojom::MojoCompositorFrameSinkPrivate,
- public cc::SurfaceFactoryClient,
- public cc::BeginFrameObserver {
+class GpuCompositorFrameSink : public cc::mojom::MojoCompositorFrameSink,
+ public cc::DisplayClient,
+ public cc::mojom::MojoCompositorFrameSinkPrivate,
+ public cc::SurfaceFactoryClient,
+ public cc::BeginFrameObserver {
public:
// TODO(fsamuel): DisplayCompositor should own
- // ServerWindowCompositorFrameSink. ServerWindowCompositorFrameSink should not
- // refer to ServerWindowCompositorFrameSinkManager.
- ServerWindowCompositorFrameSink(
+ // GpuCompositorFrameSink. GpuCompositorFrameSink should not
+ // refer to GpuCompositorFrameSinkManager.
+ GpuCompositorFrameSink(
scoped_refptr<DisplayCompositor> display_compositor,
const cc::FrameSinkId& frame_sink_id,
gfx::AcceleratedWidget widget,
@@ -58,7 +57,7 @@ class ServerWindowCompositorFrameSink
cc::mojom::MojoCompositorFrameSinkRequest request,
cc::mojom::MojoCompositorFrameSinkClientPtr client);
- ~ServerWindowCompositorFrameSink() override;
+ ~GpuCompositorFrameSink() override;
// cc::mojom::MojoCompositorFrameSink:
void SetNeedsBeginFrame(bool needs_begin_frame) override;
@@ -98,11 +97,11 @@ class ServerWindowCompositorFrameSink
// TODO(fsamuel): We hold a reference to DisplayCompositor so we can talk to
// SurfaceManager in the destructor. In the future, DisplayCompositor will own
- // ServerWindowCompositorFrameSink.
+ // GpuCompositorFrameSink.
scoped_refptr<DisplayCompositor> display_compositor_;
gfx::Size last_submitted_frame_size_;
// ServerWindowCompositorFrameSink holds a cc::Display if it created with
// non-null gfx::AcceleratedWidget. In the window server, the display root
// window's CompositorFrameSink will have a valid gfx::AcceleratedWidget.
std::unique_ptr<cc::Display> display_;
@@ -130,11 +129,11 @@ class ServerWindowCompositorFrameSink
cc::mojom::MojoCompositorFrameSinkClientPtr client_;
mojo::Binding<cc::mojom::MojoCompositorFrameSink> binding_;
- DISALLOW_COPY_AND_ASSIGN(ServerWindowCompositorFrameSink);
+ DISALLOW_COPY_AND_ASSIGN(GpuCompositorFrameSink);
};
} // namespace ws
} // namespace ui
-#endif // SERVICES_UI_WS_SERVER_WINDOW_COMPOSITOR_FRAME_SINK_H_
+#endif // SERVICES_UI_WS_GPU_COMPOSITOR_FRAME_SINK_H_
« no previous file with comments | « services/ui/ws/BUILD.gn ('k') | services/ui/ws/gpu_compositor_frame_sink.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -98,11 +97,11 @@ class ServerWindowCompositorFrameSink
scoped_refptr<DisplayCompositor> display_compositor_;
gfx::Size last_submitted_frame_size_;
- // ServerWindowCompositorFrameSink holds a cc::Display if it created with
+ // GpuCompositorFrameSink holds a cc::Display if it created with
// non-null gfx::AcceleratedWidget. In the window server, the display root
// window's CompositorFrameSink will have a valid gfx::AcceleratedWidget.
This is Rietveld 408576698